"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var _ = require("lodash");
var ListShowComponent = (function () {
    function ListShowComponent() {
        this.showData = [];
        this.hideData = [];
        this.hideDataFlag = true;
        this.removeItemEmit = new core_1.EventEmitter();
    }
    ListShowComponent.prototype.ngOnInit = function () {
        this.showKey = this.showKey || 'name';
        this.idKey = this.idKey || 'id';
        this.data = this.data || [];
        this.calcBoxWidth();
    };
    ListShowComponent.prototype.calcBoxWidth = function () {
        var box = this.listBox.nativeElement;
        var boxWidth = box.offsetWidth;
        var itemWidth = this.width || 80;
        if (this.data.length * (itemWidth - 0 + 20) < boxWidth - 100) {
            this.showData = _.cloneDeep(this.data);
        }
        else {
            var i = 0;
            for (i; i < this.data.length; i++) {
                if (i * (itemWidth - 0 + 20) > boxWidth - 120) {
                    i = i - 1;
                    break;
                }
            }
            this.showData = _.cloneDeep(this.data.slice(0, i));
            this.hideData = _.cloneDeep(this.data.slice(i));
        }
    };
    ListShowComponent.prototype.addItem = function (item) {
        this.data.push(item);
        if (this.hideData.length > 0) {
            this.hideData.push(item);
        }
        else {
            this.calcBoxWidth();
        }
    };
    ListShowComponent.prototype.removeItem = function (item, ev) {
        for (var i = 0; i < this.data.length; i++) {
            if (this.data[i][this.idKey] == item[this.idKey]) {
                this.data.splice(i, 1);
                break;
            }
        }
        this.calcBoxWidth();
        if (ev) {
            this.removeItemEmit.emit(item);
        }
    };
    ListShowComponent.prototype.toggleHideData = function (ev) {
        ev.stopPropagation();
        this.hideDataFlag = !this.hideDataFlag;
    };
    ListShowComponent.prototype.onDocumentClick = function (ev) {
        this.hideDataFlag = true;
    };
    ListShowComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'dc-list-show',
                    template: "\n    <div class=\"show-box\" #listBox>\n      <div class=\"show-list\" [style.width]=\"width + 'px'\" *ngFor=\"let item of showData\">\n        {{item[showKey]}}\n        <span *ngIf=\"canDelete\" (click)=\"removeItem(item, $event)\">x</span>\n      </div>\n      <div class=\"show-more\" (click)=\"toggleHideData($event)\" *ngIf=\"hideData && hideData.length > 0\">hideData({{hideData.length}})</div>\n    </div>\n    <div *ngIf=\"!hideDataFlag\" (click)=\"$event.stopPropagation()\" >\n      <div *ngFor=\"let item of hideData\">\n        {{item[showKey]}}\n        <span *ngIf=\"canDelete\" (click)=\"removeItem(item, $event)\">x</span>\n      </div>\n    </div>\n  ",
                    styles: [
                        "\n      .show-box {\n        display: flex;\n        flex-direction: row;\n        align-items: center;\n      }\n\n      .show-list {\n        border: 1px solid red;\n        height: 30px;\n        line-height: 30px;\n        text-align: center;\n        width: 80px;\n        text-overflow: ellipsis;\n        overflow: hidden;\n        margin-right: 20px;\n        flex-shrink: 0;\n      }\n\n      .show-more {\n        width: 100px;\n      }\n    "
                    ]
                },] },
    ];
    /** @nocollapse */
    ListShowComponent.ctorParameters = function () { return []; };
    ListShowComponent.propDecorators = {
        "data": [{ type: core_1.Input },],
        "width": [{ type: core_1.Input },],
        "showKey": [{ type: core_1.Input },],
        "idKey": [{ type: core_1.Input },],
        "canDelete": [{ type: core_1.Input },],
        "removeItemEmit": [{ type: core_1.Output },],
        "listBox": [{ type: core_1.ViewChild, args: ['listBox',] },],
        "onDocumentClick": [{ type: core_1.HostListener, args: ['document:click', ['$event'],] },],
    };
    return ListShowComponent;
}());
exports.ListShowComponent = ListShowComponent;
//# sourceMappingURL=list.show.component.js.map